//Создание задачи диспетчерского вызова прочих задач
function [allActivateState]=SetActivateStateExecPoints(ActivateState,..//Активированы или деактивированы ли точки запуска
                                                       pauseSeconds,..//Время паузы (в секундах)
                                                       updateCommandPoints..//Нужно ли обновлять командные точки
                                                       )
    //Анализируем аргументы
    select argn(2)
    case 0 then
        error('The function SetActivateStateExecPoints takes 1, 2 or 3 arguments');
    case 1 then
        pauseSeconds = 0;//Время паузы (в секундах)
        updateCommandPoints = %t;
    case 2 then
        if type(pauseSeconds) == 4 then
            updateCommandPoints = pauseSeconds;
            pauseSeconds = 0;//Время паузы (в секундах)
        else
            updateCommandPoints = %t;
        end
    end
    
    //Записывем в файл состояние активации или деактивации точек запуска сайлаба
    allActivateState = and(ActivateState);//Кластер активирован, когда все точки активированы
    fullActivateStateFileName = fullfile(SCIHOME,'LanchingTasksInformation','ActivateState.txt');//Полное имя файла состояния активации или деактивации точек запуска сайлаба
    if allActivateState then
        mputl("1",fullActivateStateFileName);//Записываем состояние активируемости кластера
    else
        mputl("0",fullActivateStateFileName);//Записываем состояние активируемости кластера
    end
    
    //Берем текущие активные состояния
    if updateCommandPoints then
        oldActivateState = GetActivateStateExecPoints();
    end
        
    //Записываем в точки состояние активации или деактивации точек запуска сайлаба
    allCommandPoints = GetCommandPoints()([1, 2],:);
    CommandPointsExec = allCommandPoints(2,:);//Получаем точки запуска
    PathToExecPoints = GetPathToExecPoints();//Получаем полное имя пути к точкам запуска
    fullCommandPointsExec = fullfile(PathToExecPoints,CommandPointsExec);//Полные имена точек запуска
    nCommandPointsExec = size(CommandPointsExec,'*');//Число точек запуска
    if size(ActivateState,'*') == 1 then
        ActivateState = repmat(ActivateState,[1,nCommandPointsExec]);
    end
    for ind=1:nCommandPointsExec
        //Формируем полное имя файла состояние активации или деактивации точек запуска сайлаба в точке запуска
        fullCommandPointExecActivateStateFile = fullfile(fullCommandPointsExec(ind),'ExecScilab');
        
        //Пишем состояние активации или деактивации точек запуска сайлаба в файл
        if ActivateState(ind) then
            mputl("1",fullCommandPointExecActivateStateFile);
        else
            mputl("0",fullCommandPointExecActivateStateFile);
        end
    end
    
    //Обновляем точки
    if updateCommandPoints then
        //Берем неактивные точки, активные в прошлом
        noActiveCommandPoints = allCommandPoints(1,(~ActivateState) & oldActivateState);
        
        //Функция чтения команды
        function [messages,isQuesion]=readCommandFromFile(CommandPoint)
            //Читаем информацию из файла
            [messages,..//Сообщения
             isNewQuesion,..//Новый вопрос ли?
             isQuesion,..
             isAnsweredQuesion]=ReadCommandFromFile(CommandPoint);
             
            //Это вопрос, на который не получен ответ?
            isQuesion = isQuesion && (~isAnsweredQuesion);
        endfunction
        
        //Функция обработки ошибок
        function ErrorFunctionCmd(regCode,errMsg,CommandPoint,ProjectName)
            if regCode == 0 then
                disp('Project ' + ProjectName + ': ' + CommandPoint + ' is busy');
            else
                msgStr = 'Project ' + ProjectName + ': ' + CommandPoint + ': Error execute, Code: ' + string(regCode) + ': ';
                if size(errMsg,'*') > 1 then
                    disp(msgStr);
                    disp(errMsg);
                else
                    msgStr = msgStr + errMsg;
                    disp(msgStr);
                end
            end
        endfunction
        
        //Функция проверки точки обмена сообщениями
        function regCode = IsRegisteredMessageFilePointCmd(CommandPoint)
            if isRegisteredMessageFilePoint(CommandPoint) &&..
               AskExecPoints(CommandPoint) then
                regCode = 0;
            else
                regCode = 1;
            end
        endfunction
        
        //Перезагружаем активные точки
        EndCommandPoints('ErrorFunctionCmd','disp','readCommandFromFile',..
                         "AskToQuensionToFile",'IsRegisteredMessageFilePointCmd',..
                         noActiveCommandPoints,GetProjectName(),pauseSeconds);
        
        //Пишем в облачный файл
        fullFileActivateStateName = fullfile(SCIHOME,'LanchingTasksInformation','ActivateState.csv');//Полное имя файла
        sActivateState = zeros(ActivateState);
        sActivateState(ActivateState) = 1;
        write_csv(string(sActivateState),fullFileActivateStateName);
    end
endfunction
